changeset 180:36d4388ed131

sync
author Sebastien Jodogne <s.jodogne@gmail.com>
date Thu, 04 Jan 2018 17:38:33 +0100
parents 8fe42ddf0807
children 7c3e88ed1b04
files Orthanc/Core/Endianness.h Orthanc/Core/PrecompiledHeaders.h Orthanc/Resources/CMake/Compiler.cmake
diffstat 3 files changed, 13 insertions(+), 4 deletions(-) [+]
line wrap: on
line diff
--- a/Orthanc/Core/Endianness.h	Thu Jan 04 09:50:04 2018 +0100
+++ b/Orthanc/Core/Endianness.h	Thu Jan 04 17:38:33 2018 +0100
@@ -101,6 +101,16 @@
 
 
 /********************************************************************
+ ** OPENBSD ARCHITECTURES
+ ********************************************************************/
+
+#if defined(__OpenBSD__)
+#  define ORTHANC_HAS_BUILTIN_BYTE_SWAP 1
+#  include <endian.h>
+#endif
+
+
+/********************************************************************
  ** APPLE ARCHITECTURES (including OS X)
  ********************************************************************/
 
--- a/Orthanc/Core/PrecompiledHeaders.h	Thu Jan 04 09:50:04 2018 +0100
+++ b/Orthanc/Core/PrecompiledHeaders.h	Thu Jan 04 17:38:33 2018 +0100
@@ -59,8 +59,6 @@
 #include "Toolbox.h"
 
 #if ORTHANC_ENABLE_DCMTK == 1
-#  include "DicomParsing/ParsedDicomFile.h"
-
 // Headers from DCMTK used in Orthanc headers 
 #  include <dcmtk/dcmdata/dcdatset.h>
 #  include <dcmtk/dcmdata/dcfilefo.h>
--- a/Orthanc/Resources/CMake/Compiler.cmake	Thu Jan 04 09:50:04 2018 +0100
+++ b/Orthanc/Resources/CMake/Compiler.cmake	Thu Jan 04 17:38:33 2018 +0100
@@ -99,8 +99,9 @@
     link_libraries(dl)
   endif()
 
-  if (NOT ${CMAKE_SYSTEM_NAME} STREQUAL "FreeBSD")
-    # The "--as-needed" linker flag is not available on FreeBSD
+  if (NOT ${CMAKE_SYSTEM_NAME} STREQUAL "FreeBSD" AND
+      NOT ${CMAKE_SYSTEM_NAME} STREQUAL "OpenBSD")
+    # The "--as-needed" linker flag is not available on FreeBSD and OpenBSD
     set(CMAKE_EXE_LINKER_FLAGS "${CMAKE_EXE_LINKER_FLAGS} -Wl,--as-needed")
     set(CMAKE_MODULE_LINKER_FLAGS "${CMAKE_MODULE_LINKER_FLAGS} -Wl,--as-needed")
     set(CMAKE_SHARED_LINKER_FLAGS "${CMAKE_SHARED_LINKER_FLAGS} -Wl,--as-needed")